# Changelog

All notable changes to this project will be documented in this file.

## [Unreleased]

## [0.1.0] - 2023-11-16

### Added

- `swgo.psa.adaptive_centroid` function to calculate a robust pulse centroid
